@@ -4,9 +4,9 @@ from .common import configure_logger
 # Initialize logger configuration at module load
 configure_logger()
 
-from .config import ensure_config_loaded, update_config
+from .config import ensure_config_loaded, config
 
 # Initialize the config dict
 ensure_config_loaded()
-
-__version__ = "2.0.0"
+# Import scheduler types
+from .variable import *
