@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 # Linear task section
-from .cpu_asyncio_task import CpuAsyncTask
+from .cpu_asyncio_task import CpuAsyncioTask
 from .cpu_liner_task import CpuLinerTask
 
 # Asynchronous task section
-from .io_asyncio_task import IoAsyncTask
+from .io_asyncio_task import IoAsyncioTask
 from .io_liner_task import IoLinerTask
 
 # Task timer
 from .timer_task import TimerTask
 
 io_liner_task = IoLinerTask()
-io_async_task = IoAsyncTask()
+io_asyncio_task = IoAsyncioTask()
 
 cpu_liner_task = CpuLinerTask()
-cpu_async_task = CpuAsyncTask()
+cpu_asyncio_task = CpuAsyncioTask()
 
 timer_task = TimerTask()
