@@ -4,7 +4,7 @@ import asyncio
 import queue
 import threading
 import time
-from concurrent.futures import ProcessPoolExecutor, Future
+from concurrent.futures import ProcessPoolExecutor, Future, BrokenExecutor
 from functools import partial
 from multiprocessing import Manager
 from typing import Callable, Dict, Tuple, Optional, Any
@@ -12,8 +12,11 @@ from typing import Callable, Dict, Tuple, Optional, Any
 from ..common import logger
 from ..config import config
 from ..manager import task_status_manager
-from ..stopit import ProcessTaskManager, skip_on_demand, StopException
-from ..utils import worker_initializer_asyncio
+from ..control import ThreadTerminator, ProcessTaskManager, StopException, ThreadSuspender
+from ..utils import worker_initializer
+
+_threadsuspender = ThreadSuspender()
+_threadterminator = ThreadTerminator()
 
 
 async def _execute_task_async(task: Tuple[bool, str, str, Callable, Tuple, Dict],
@@ -36,17 +39,18 @@ async def _execute_task_async(task: Tuple[bool, str, str, Callable, Tuple, Dict]
     """
     timeout_processing, task_name, task_id, func, args, kwargs = task
 
-    with skip_on_demand() as skip_ctx:
-        task_manager.add(skip_ctx, task_id)
+    with _threadterminator.terminate_control() as terminate_ctx:
+        with _threadsuspender.suspend_context() as pause_ctx:
+            task_manager.add(terminate_ctx, pause_ctx, task_id)
 
-        task_status_queue.put(("running", task_id, None, time.time(), None, None, None))
-        logger.info(f"Start running cpu asyncio task, task ID: {task_id}")
+            task_status_queue.put(("running", task_id, None, time.time(), None, None, None))
+            logger.debug(f"Start running cpu asyncio task, task ID: {task_id}")
 
-        if timeout_processing:
-            return_results = await asyncio.wait_for(func(*args, **kwargs),
-                                                    timeout=config["watch_dog_time"])
-        else:
-            return_results = await func(*args, **kwargs)
+            if timeout_processing:
+                return_results = await asyncio.wait_for(func(*args, **kwargs),
+                                                        timeout=config["watch_dog_time"])
+            else:
+                return_results = await func(*args, **kwargs)
 
     return return_results
 
@@ -88,10 +92,13 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
         return_results = "error happened"
 
     except Exception as e:
-        if not "Cannot close a running event loop" in str(e):
-            logger.error(f"Cpu asyncio task | {task_id} | execution failed: {e}")
-            task_status_queue.put(("failed", task_id, None, None, None, e, None))
-            return_results = "error happened"
+        if config["exception_thrown"]:
+            raise
+
+        # if not "Cannot close a running event loop" in str(e):
+        logger.error(f"Cpu asyncio task | {task_id} | execution failed: {e}")
+        task_status_queue.put(("failed", task_id, None, None, None, e, None))
+        return_results = "error happened"
 
     finally:
         if return_results != "error happened":
@@ -104,7 +111,7 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
     return return_results
 
 
-class CpuAsyncTask:
+class CpuAsyncioTask:
     """
     Linear task manager class, responsible for managing the scheduling, execution, and monitoring of linear tasks.
     """
@@ -158,8 +165,8 @@ class CpuAsyncTask:
                     task = self._task_status_queue.get(timeout=0.1)
                     status, task_id, task_name, start_time, end_time, error, timeout_processing = task
                     task_status_manager.add_task_status(task_id, task_name, status, start_time, end_time, error,
-                                                        timeout_processing)
-            except queue.Empty:
+                                                        timeout_processing, "cpu_asyncio")
+            except (queue.Empty, ValueError):
                 pass  # Ignore empty queue exceptions
             finally:
                 time.sleep(0.1)
@@ -170,7 +177,7 @@ class CpuAsyncTask:
                  task_id: str,
                  func: Callable,
                  *args,
-                 **kwargs) -> bool:
+                 **kwargs) -> Any:
         """
         Add the task to the scheduler.
 
@@ -187,7 +194,7 @@ class CpuAsyncTask:
         """
         try:
             with self._scheduler_lock:
-                if self._task_queue.qsize() >= config["io_liner_task"]:
+                if self._task_queue.qsize() >= config["cpu_asyncio_task"]:
                     return False
 
                 if task_name in [details[1] for details in self._running_tasks.values()]:
@@ -211,8 +218,8 @@ class CpuAsyncTask:
 
                 return True
         except Exception as e:
-            logger.error(f"Cpu asyncio task | {task_id} | error adding task: {e}")
-            return False
+            logger.debug(f"Cpu asyncio task | {task_id} | error adding task: {e}")
+            return e
 
     def _start_scheduler(self) -> None:
         """
@@ -239,19 +246,16 @@ class CpuAsyncTask:
             # Check if there are any running tasks
             if not self._task_queue.empty() or not len(self._running_tasks) == 0:
                 if system_operations:
-                    logger.warning(f"Cpu liner task | detected running tasks | stopping operation terminated")
+                    logger.debug(f"Cpu liner task | detected running tasks | stopping operation terminated")
                     return
 
             if force_cleanup:
-                logger.warning("Force stopping scheduler and cleaning up tasks")
+                logger.debug("Force stopping scheduler and cleaning up tasks")
                 self.stop_all_running_task()
-                # Ensure the executor is properly shut down
-                if self._executor:
-                    self._executor.shutdown(wait=False, cancel_futures=True)
-            else:
-                # Ensure the executor is properly shut down
-                if self._executor:
-                    self._executor.shutdown(wait=True, cancel_futures=True)
+
+            # Ensure the executor is properly shut down
+            if self._executor:
+                self._executor.shutdown(wait=True, cancel_futures=True)
 
             # Wait for all running tasks to complete
             self._scheduler_stop_event.set()
@@ -277,12 +281,12 @@ class CpuAsyncTask:
             self._idle_timer = None
             self._task_results = {}
 
-            # logger.info(
+            # logger.debug(
             #     "Scheduler and event loop have stopped, all resources have been released and parameters reset")
 
     def stop_all_running_task(self):
         for task_id in self._running_tasks.keys():
-            self._task_status_queue.put(task_id)
+            self._task_signal_transmission.put((task_id, "kill"))
 
         while not self._task_status_queue.qsize() == 0:
             time.sleep(0.1)
@@ -292,7 +296,7 @@ class CpuAsyncTask:
         Scheduler function, fetch tasks from the task queue and submit them to the process pool for execution.
         """
         with ProcessPoolExecutor(max_workers=int(config["cpu_asyncio_task"]),
-                                 initializer=worker_initializer_asyncio) as executor:
+                                 initializer=worker_initializer) as executor:
             self._executor = executor
             while not self._scheduler_stop_event.is_set():
                 with self._condition:
@@ -311,7 +315,7 @@ class CpuAsyncTask:
                 with self._lock:
                     future = executor.submit(_execute_task, task, self._task_status_queue,
                                              self._task_signal_transmission)
-                    self._running_tasks[task_id] = [future, task_name]
+                    self._running_tasks[task_id] = [future, task_name, ]
 
                     future.add_done_callback(partial(self._task_done, task_id))
 
@@ -333,15 +337,11 @@ class CpuAsyncTask:
                 if result != "error happened":
                     with self._lock:
                         self._task_results[task_id] = result
-        except KeyboardInterrupt:
+        except (KeyboardInterrupt, BrokenExecutor):
             # Prevent problems caused by exit errors
             logger.warning(f"Cpu asyncio task | {task_id} | cancelled, forced termination")
             self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
 
-        except Exception as e:
-            logger.error(f"Cpu asyncio task | {task_id} | execution failed in callback: {e}")
-            self._task_status_queue.put(("failed", task_id, None, None, None, e, None))
-
         finally:
             # Make sure the Future object is deleted
             with self._lock:
@@ -396,10 +396,14 @@ class CpuAsyncTask:
             bool: Whether the task was successfully force stopped.
         """
         if self._running_tasks.get(task_id) is None:
-            logger.warning(f"Cpu asyncio task | {task_id} | does not exist or is already completed")
+            logger.debug(f"Cpu asyncio task | {task_id} | does not exist or is already completed")
             return False
 
-        self._task_signal_transmission.put(task_id)
+        future = self._running_tasks[task_id][0]
+        if not future.running():
+            future.cancel()
+        else:
+            self._task_signal_transmission.put((task_id, "kill"))
 
         self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
 
@@ -409,6 +413,29 @@ class CpuAsyncTask:
 
         return True
 
+    def pause_and_resume_task(self,
+                              task_id: str, action: str) -> bool:
+        """
+        pause and resume a task by its task ID.
+
+        :param task_id: Task ID.
+        :param action: Task action.
+        :return: bool: Whether the task was successfully pause and resume.
+        """
+        if self._running_tasks.get(task_id) is None:
+            logger.debug(f"Cpu asyncio task | {task_id} | does not exist or is already completed")
+            return False
+
+        else:
+            if action == "pause":
+                self._task_signal_transmission.put((task_id, "pause"))
+                self._task_status_queue.put(("waiting", task_id, None, None, None, None, None))
+            elif action == "resume":
+                self._task_signal_transmission.put((task_id, "resume"))
+                self._task_status_queue.put(("running", task_id, None, None, None, None, None))
+
+        return True
+
     # Obtain the information returned by the corresponding task
     def get_task_result(self,
                         task_id: str) -> Optional[Any]:
