@@ -3,16 +3,24 @@
 import queue
 import threading
 import time
-from concurrent.futures import ProcessPoolExecutor, Future
+import math
+from concurrent.futures import ProcessPoolExecutor, Future, BrokenExecutor
 from functools import partial
 from multiprocessing import Manager
 from typing import Callable, Dict, Tuple, Optional, Any
 
 from ..common import logger
 from ..config import config
-from ..manager import task_status_manager
-from ..stopit import skip_on_demand, ProcessTaskManager, StopException, ThreadingTimeout, TimeoutException
-from ..utils import worker_initializer_liner
+from ..manager import task_status_manager, SharedTaskDict
+from ..control import ThreadTerminator, ProcessTaskManager, StopException, ThreadingTimeout, TimeoutException, \
+    ThreadSuspender
+from ..utils import worker_initializer
+
+from ..scheduler_tools import TaskCounter
+
+_task_counter = TaskCounter("cpu_liner_task")
+_threadsuspender = ThreadSuspender()
+_threadterminator = ThreadTerminator()
 
 
 def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
@@ -35,26 +43,33 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
     Returns:
         Any: Result of the task execution or error message.
     """
+    # Create a shared dictionary
+    _sharedtaskdict = SharedTaskDict()
 
-    timeout_processing, task_name, task_id, func, args, kwargs = task
+    timeout_processing, task_name, task_id, func, priority, args, kwargs = task
     task_manager = ProcessTaskManager(task_signal_transmission)
     return_results = None
 
     try:
-        with skip_on_demand() as skip_ctx:
-            task_manager.add(skip_ctx, task_id)
+        with _threadterminator.terminate_control() as terminate_ctx:
+            with _threadsuspender.suspend_context() as pause_ctx:
+                task_manager.add(terminate_ctx, pause_ctx, task_id)
+
+                task_status_queue.put(("running", task_id, None, time.time(), None, None, None))
+                logger.debug(f"Start running cpu linear task, task ID: {task_id}")
+                if timeout_processing:
+                    with ThreadingTimeout(seconds=config["watch_dog_time"], swallow_exc=False):
+                        # Whether to pass in the task manager to facilitate other thread management
+                        if config["thread_management"]:
+                            share_info = (task_manager, _threadterminator, StopException, ThreadingTimeout,
+                                          TimeoutException, _threadsuspender, task_status_queue)
+                            return_results = func(share_info, _sharedtaskdict, task_signal_transmission, *args,
+                                                  **kwargs)
+                        else:
+                            return_results = func(*args, **kwargs)
+                else:
+                    return_results = func(*args, **kwargs)
 
-            task_status_queue.put(("running", task_id, None, time.time(), None, None, None))
-            logger.info(f"Start running cpu linear task, task ID: {task_id}")
-            if timeout_processing:
-                with ThreadingTimeout(seconds=config["watch_dog_time"], swallow_exc=False):
-                    # Whether to pass in the task manager to facilitate other thread management
-                    if config["thread_management"]:
-                        return_results = func(task_manager, *args, **kwargs)
-                    else:
-                        return_results = func(*args, **kwargs)
-            else:
-                return_results = func(*args, **kwargs)
 
     except (StopException, KeyboardInterrupt):
         logger.warning(f"Cpu linear task | {task_id} | cancelled, forced termination")
@@ -67,17 +82,25 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
         return_results = "error happened"
 
     except Exception as e:
+        if config["exception_thrown"]:
+            raise
+
         logger.error(f"Cpu linear task | {task_id} | execution failed: {e}")
         task_status_queue.put(("failed", task_id, None, None, None, e, None))
         return_results = "error happened"
 
     finally:
+        task_manager.remove(task_id)
+
+        # Terminate all other threads under the main thread
+        if config["thread_management"]:
+            task_manager.terminate_task_all()
+
         if return_results != "error happened":
             try:
                 task_status_queue.put(("completed", task_id, None, None, time.time(), None, None))
             except BrokenPipeError:
                 pass
-        task_manager.remove(task_id)
 
         return return_results
 
@@ -136,9 +159,9 @@ class CpuLinerTask:
                     task = self._task_status_queue.get(timeout=0.1)
                     status, task_id, task_name, start_time, end_time, error, timeout_processing = task
                     task_status_manager.add_task_status(task_id, task_name, status, start_time, end_time, error,
-                                                        timeout_processing)
+                                                        timeout_processing, "cpu_liner_task")
 
-            except queue.Empty:
+            except (queue.Empty, ValueError):
                 pass  # Ignore empty queue exceptions
             finally:
                 time.sleep(0.1)
@@ -148,7 +171,8 @@ class CpuLinerTask:
                  task_name: str,
                  task_id: str,
                  func: Callable,
-                 *args, **kwargs) -> bool:
+                 priority: str,
+                 *args, **kwargs) -> Any:
         """
         Add the task to the scheduler.
 
@@ -157,6 +181,7 @@ class CpuLinerTask:
             task_name (str): Task name.
             task_id (str): Task ID.
             func (Callable): The function to execute.
+            priority (str): Mission importance level.
             *args: Arguments to pass to the function.
             **kwargs: Keyword arguments to pass to the function.
 
@@ -165,11 +190,15 @@ class CpuLinerTask:
         """
         try:
             with self._scheduler_lock:
-                if self._task_queue.qsize() >= config["cpu_liner_task"]:
-                    return False
+                if not _task_counter.is_high_priority(priority):
+                    if self._task_queue.qsize() >= config["cpu_liner_task"]:
+                        return False
 
-                if task_name in [details[1] for details in self._running_tasks.values()]:
-                    return False
+                    if task_name in [details[1] for details in self._running_tasks.values()]:
+                        return False
+                else:
+                    if not _task_counter.add(math.ceil(config["cpu_liner_task"])):
+                        return False
 
                 if self._scheduler_stop_event.is_set() and not self._scheduler_started:
                     self._join_scheduler_thread()
@@ -177,7 +206,7 @@ class CpuLinerTask:
                 # Reduce the granularity of the lock
                 self._task_status_queue.put(("waiting", task_id, None, None, None, None, None))
 
-                self._task_queue.put((timeout_processing, task_name, task_id, func, args, kwargs))
+                self._task_queue.put((timeout_processing, task_name, task_id, func, priority, args, kwargs))
 
                 if not self._scheduler_started:
                     self._start_scheduler()
@@ -189,8 +218,8 @@ class CpuLinerTask:
 
                 return True
         except Exception as e:
-            logger.error(f"Cpu linear task | {task_id} | error adding task: {e}")
-            return False
+            logger.debug(f"Cpu linear task | {task_id} | error adding task: {e}")
+            return e
 
     def _start_scheduler(self) -> None:
         """
@@ -215,19 +244,16 @@ class CpuLinerTask:
             # Check if there are any running tasks
             if not self._task_queue.empty() or not len(self._running_tasks) == 0:
                 if system_operations:
-                    logger.warning(f"Cpu liner task | detected running tasks | stopping operation terminated")
+                    logger.debug(f"Cpu liner task | detected running tasks | stopping operation terminated")
                     return None
 
             if force_cleanup:
-                logger.warning("Force stopping scheduler and cleaning up tasks")
+                logger.debug("Force stopping scheduler and cleaning up tasks")
                 self.stop_all_running_task()
-                # Ensure the executor is properly shut down
-                if self._executor:
-                    self._executor.shutdown(wait=False, cancel_futures=True)
-            else:
-                # Ensure the executor is properly shut down
-                if self._executor:
-                    self._executor.shutdown(wait=True, cancel_futures=True)
+
+            # Ensure the executor is properly shut down
+            if self._executor:
+                self._executor.shutdown(wait=True, cancel_futures=True)
 
             # Wait for all running tasks to complete
             self._scheduler_stop_event.set()
@@ -253,22 +279,22 @@ class CpuLinerTask:
             self._idle_timer = None
             self._task_results = {}
 
-            # logger.info(
-            #     "Scheduler and event loop have stopped, all resources have been released and parameters reset")
+            logger.debug(
+                "Scheduler and event loop have stopped, all resources have been released and parameters reset")
 
     def stop_all_running_task(self):
         for task_id in self._running_tasks.keys():
-            self._task_status_queue.put(task_id)
+            self._task_signal_transmission.put((task_id, "kill"))
 
-        while not self._task_status_queue.qsize() == 0:
+        while not self._task_signal_transmission.qsize() == 0:
             time.sleep(0.1)
 
     def _scheduler(self) -> None:
         """
         Scheduler function, fetch tasks from the task queue and submit them to the process pool for execution.
         """
-        with ProcessPoolExecutor(max_workers=int(config["cpu_liner_task"]),
-                                 initializer=worker_initializer_liner) as executor:
+        with ProcessPoolExecutor(max_workers=int(config["cpu_liner_task"] + math.ceil(config["cpu_liner_task"] / 2)),
+                                 initializer=worker_initializer) as executor:
             self._executor = executor
             while not self._scheduler_stop_event.is_set():
                 with self._condition:
@@ -283,12 +309,13 @@ class CpuLinerTask:
 
                     task = self._task_queue.get()
 
-                timeout_processing, task_name, task_id, func, args, kwargs = task
+                timeout_processing, task_name, task_id, func, priority, args, kwargs = task
                 with self._lock:
                     future = executor.submit(_execute_task, task, self._task_status_queue,
                                              self._task_signal_transmission)
-                    self._running_tasks[task_id] = [future, task_name]
+                    self._running_tasks[task_id] = [future, task_name, priority]
                     future.add_done_callback(partial(self._task_done, task_id))
+                _task_counter.schedule_tasks(self._running_tasks)
 
     def _task_done(self,
                    task_id: str,
@@ -306,10 +333,11 @@ class CpuLinerTask:
                 if result != "error happened":
                     with self._lock:
                         self._task_results[task_id] = result
+        except (KeyboardInterrupt, BrokenExecutor):
+            # Prevent problems caused by exit errors
+            logger.debug(f"Cpu linear task | {task_id} | cancelled, forced termination")
+            self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
 
-        except Exception as e:
-            logger.error(f"Cpu linear task | {task_id} | execution failed in callback: {e}")
-            self._task_status_queue.put(("failed", task_id, None, None, None, e, None))
         finally:
             # Make sure the Future object is deleted
             with self._lock:
@@ -364,10 +392,17 @@ class CpuLinerTask:
         :return: bool: Whether the task was successfully force stopped.
         """
         if self._running_tasks.get(task_id) is None and main_task:
-            logger.warning(f"Cpu linear task | {task_id} | does not exist or is already completed")
+            logger.debug(f"Cpu linear task | {task_id} | does not exist or is already completed")
             return False
-
-        self._task_signal_transmission.put(task_id)
+        # Handling situations on non-main threads
+        if main_task:
+            future = self._running_tasks[task_id][0]
+            if not future.running():
+                future.cancel()
+            else:
+                self._task_signal_transmission.put((task_id, "kill"))
+        else:
+            self._task_signal_transmission.put((task_id, "kill"))
 
         self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
         with self._lock:
@@ -376,6 +411,29 @@ class CpuLinerTask:
 
         return True
 
+    def pause_and_resume_task(self,
+                              task_id: str, action: str) -> bool:
+        """
+        pause and resume a task by its task ID.
+
+        :param task_id: Task ID.
+        :param action: Task action.
+        :return: bool: Whether the task was successfully pause and resume.
+        """
+        if self._running_tasks.get(task_id) is None:
+            logger.debug(f"Cpu linear task | {task_id} | does not exist or is already completed")
+            return False
+
+        else:
+            if action == "pause":
+                self._task_signal_transmission.put((task_id, "pause"))
+                self._task_status_queue.put(("waiting", task_id, None, None, None, None, None))
+            elif action == "resume":
+                self._task_signal_transmission.put((task_id, "resume"))
+                self._task_status_queue.put(("running", task_id, None, None, None, None, None))
+
+        return True
+
     # Obtain the information returned by the corresponding task
     def get_task_result(self,
                         task_id: str) -> Optional[Any]:
