@@ -9,13 +9,15 @@ from typing import Dict, Tuple, Callable, Optional, Any
 from ..common import logger
 from ..config import config
 from ..manager import task_status_manager
-from ..stopit import ThreadTaskManager
+from ..control import ThreadTaskManager, ThreadSuspender, ThreadTerminator
 
 # Create Manager instance
 _task_manager = ThreadTaskManager()
+_threadsuspender = ThreadSuspender()
+_threadterminator = ThreadTerminator()
 
 
-class IoAsyncTask:
+class IoAsyncioTask:
     """
     Asynchronous task manager class, responsible for scheduling, executing, and monitoring asynchronous tasks.
     """
@@ -58,7 +60,7 @@ class IoAsyncTask:
                  task_id: str,
                  func: Callable,
                  *args,
-                 **kwargs) -> bool:
+                 **kwargs) -> Any:
         """
         Add a task to the task queue.
 
@@ -81,7 +83,7 @@ class IoAsyncTask:
                 if self._task_queues[task_name].qsize() >= config["io_asyncio_task"]:
                     return False
 
-                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None)
+                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, "io_asyncio_task")
 
                 self._task_queues[task_name].put((timeout_processing, task_name, task_id, func, args, kwargs))
 
@@ -99,8 +101,8 @@ class IoAsyncTask:
 
                 return True
         except Exception as e:
-            logger.error(f"Error adding task | {task_id} |: {e}")
-            return False
+            logger.debug(f"Io asyncio task | {task_id} | error adding task: {e}")
+            return e
 
     # Start the scheduler
     def _start_scheduler(self,
@@ -133,7 +135,7 @@ class IoAsyncTask:
         with self._scheduler_lock:
             # Check if all tasks are completed
             if not self._task_queues[task_name].empty() or len(self._running_tasks) != 0:
-                logger.warning(f"Io asyncio task was detected to be running, and the task stopped terminating")
+                logger.debug(f"Io asyncio task was detected to be running, and the task stopped terminating")
                 return None
 
             self._scheduler_stop_event.set()
@@ -163,7 +165,7 @@ class IoAsyncTask:
             if task_name in self._task_counters:
                 del self._task_counters[task_name]
 
-            logger.info(
+            logger.debug(
                 f"Scheduler and event loop for task | {task_name} | have stopped, all resources have been released and parameters reset")
 
     def stop_all_schedulers(self,
@@ -180,11 +182,11 @@ class IoAsyncTask:
             # Check if all tasks are completed
             if not all(q.empty() for q in self._task_queues.values()) or len(self._running_tasks) != 0:
                 if system_operations:
-                    logger.warning(f"Io asyncio task was detected to be running, and the task stopped terminating")
+                    logger.debug(f"Io asyncio task was detected to be running, and the task stopped terminating")
                     return None
 
             if force_cleanup:
-                logger.warning("Force stopping all schedulers and cleaning up tasks")
+                logger.debug("Force stopping all schedulers and cleaning up tasks")
                 # Forcibly cancel all running tasks
                 _task_manager.cancel_all_tasks()
                 self._scheduler_stop_event.set()
@@ -218,8 +220,8 @@ class IoAsyncTask:
             self._idle_timers.clear()
             self._task_counters.clear()
 
-            # logger.info(
-            #     "Scheduler and event loop have stopped, all resources have been released and parameters reset")
+            logger.debug(
+                "Scheduler and event loop have stopped, all resources have been released and parameters reset")
 
     # Task scheduler
     def _scheduler(self,
@@ -249,7 +251,7 @@ class IoAsyncTask:
             # Execute the task after the lock is released
             timeout_processing, task_name, task_id, func, args, kwargs = task
             future = asyncio.run_coroutine_threadsafe(self._execute_task(task), self._event_loops[task_name])
-            _task_manager.add(future, None, task_id)
+            _task_manager.add(future, None, None, task_id)
             with self._condition:
                 self._running_tasks[task_id] = [future, task_name]
                 self._task_counters[task_name] += 1
@@ -276,34 +278,40 @@ class IoAsyncTask:
         timeout_processing, task_name, task_id, func, args, kwargs = task
         return_results = None
         try:
-            # Modify the task status
-            task_status_manager.add_task_status(task_id, None, "running", time.time(), None, None, None)
+            with _threadsuspender.suspend_context() as pause_ctx:
+                _task_manager.add(None, None, pause_ctx, task_id)
+                # Modify the task status
+                task_status_manager.add_task_status(task_id, None, "running", time.time(), None, None, None, None)
 
-            logger.info(f"Start running io asyncio task | {task_id} | ")
+                logger.debug(f"Start running io asyncio task | {task_id} | ")
 
-            # If the task needs timeout processing, set the timeout time
-            if timeout_processing:
-                return_results = await asyncio.wait_for(func(*args, **kwargs),
-                                                        timeout=config["watch_dog_time"])
-            else:
-                return_results = await func(*args, **kwargs)
+                # If the task needs timeout processing, set the timeout time
+                if timeout_processing:
+                    return_results = await asyncio.wait_for(func(*args, **kwargs),
+                                                            timeout=config["watch_dog_time"])
+                else:
+                    return_results = await func(*args, **kwargs)
 
-            # Update task status to "completed"
-            task_status_manager.add_task_status(task_id, None, "completed", None, time.time(), None, None)
+                # Update task status to "completed"
+                task_status_manager.add_task_status(task_id, None, "completed", None, time.time(), None, None, None)
 
         except asyncio.TimeoutError:
             logger.warning(f"Io asyncio task | {task_id} | timed out, forced termination")
-            task_status_manager.add_task_status(task_id, None, "timeout", None, None, None, None)
+            task_status_manager.add_task_status(task_id, None, "timeout", None, None, None, None, None)
             return_results = "error happened"
         except asyncio.CancelledError:
             logger.warning(f"Io asyncio task | {task_id} | was cancelled")
             task_status_manager.add_task_status(task_id, None, "cancelled", None, None, None,
-                                                None)
+                                                None, None)
             return_results = "error happened"
         except Exception as e:
+            if config["exception_thrown"]:
+                raise
+
             logger.error(f"Io asyncio task | {task_id} | execution failed: {e}")
-            task_status_manager.add_task_status(task_id, None, "failed", None, None, e, None)
+            task_status_manager.add_task_status(task_id, None, "failed", None, None, e, None, None)
             return_results = "error happened"
+
         finally:
             if return_results == "error happened":
                 _task_manager.remove(task_id)
@@ -394,16 +402,43 @@ class IoAsyncTask:
             bool: Whether the task was successfully force stopped.
         """
         # Read operation, no need to hold a lock
-        if not _task_manager.check(task_id):
-            logger.warning(f"Io asyncio task | {task_id} | does not exist or is already completed")
+        if self._running_tasks.get(task_id, None):
+            logger.debug(f"Io asyncio task | {task_id} | does not exist or is already completed")
             return False
 
-        _task_manager.cancel_task(task_id)
+        future = self._running_tasks[task_id][0]
+        if not future.running():
+            future.cancel()
+        else:
+            _task_manager.terminate_task(task_id)
+
         with self._condition:
             if task_id in self._task_results:
                 del self._task_results[task_id]
         return True
 
+    def pause_and_resume_task(self,
+                              task_id: str, action: str) -> bool:
+        """
+        Pause and resume a task by its task ID.
+        :param task_id: Task ID.
+        :param action: Task action.
+        :return: bool: Whether the task was successfully pause and resume.
+        """
+        if not self._running_tasks.get(task_id, None):
+            logger.debug(f"Io asyncio task | {task_id} | does not exist or is already completed")
+            return False
+
+        else:
+            if action == "pause":
+                _task_manager.pause_task(task_id)
+                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, None)
+            elif action == "resume":
+                _task_manager.resume_task(task_id)
+                task_status_manager.add_task_status(task_id, None, "running", None, None, None, None, None)
+
+        return True
+
     # Obtain the information returned by the corresponding task
     def get_task_result(self,
                         task_id: str) -> Optional[Any]:
@@ -449,4 +484,4 @@ class IoAsyncTask:
                 if task_name in self._scheduler_threads and self._scheduler_threads[task_name].is_alive():
                     self._scheduler_threads[task_name].join(timeout=1.0)  # Wait up to 1 second
             except Exception as e:
-                logger.error(f"Io asyncio task | stopping event loop | error occurred: {e}")
+                logger.debug(f"Io asyncio task | stopping event loop | error occurred: {e}")
